==> kget-4.10.95.tar.xz: kget-4.10.95/desktop/kget.desktop.cmake <==
# KDE Config File
[Desktop Entry]
Type=Application
Exec=kget -caption %c %i %U
Icon=kget
Terminal=false
MimeType=@SUPPORTED_KGET_MIMETYPES@
Name=KGet
Name[ar]=KGet
Name[ast]=KGet
Name[be]=KGet
Name[bg]=KGet
Name[bn]=কে-গেট
Name[br]=KGet
Name[bs]=KGet
Name[ca]=KGet
Name[ca@valencia]=KGet
Name[cs]=KGet
Name[cy]=KNôl
Name[da]=KGet
Name[de]=KGet
Name[el]=KGet
Name[en_GB]=KGet
Name[eo]=KGet
Name[es]=KGet
Name[et]=KGet
Name[eu]=KGet
Name[fi]=KGet
Name[fr]=KGet
Name[ga]=KGet
Name[gl]=KGet
Name[he]=KGet
Name[hi]=के-गेट
Name[hne]=के-गेट
Name[hr]=KGet
Name[hu]=KGet
Name[ia]=KGet
Name[is]=KGet
Name[it]=KGet
Name[ja]=KGet
Name[kk]=KGet
Name[km]=KGet
Name[ko]=KGet
Name[lt]=KGet
Name[lv]=KGet
Name[mk]=KGet
Name[ml]=കെഗെറ്റ്
Name[mr]=के-गेट
Name[ms]=KGet
Name[nb]=KGet
Name[nds]=KGet
Name[ne]=केडीई गेट
Name[nl]=KGet
Name[nn]=KGet
Name[pa]=ਕੇ-ਗੈੱਟ
Name[pl]=KGet
Name[pt]=KGet
Name[pt_BR]=KGet
Name[ro]=KGet
Name[ru]=KGet
Name[se]=KGet
Name[si]=KGet
Name[sk]=KGet
Name[sl]=KGet
Name[sq]=KGet
Name[sr]=К‑гет
Name[sr@ijekavian]=К‑гет
Name[sr@ijekavianlatin]=KGet
Name[sr@latin]=KGet
Name[sv]=Kget
Name[ta]=கேகெட்
Name[tg]=KGet
Name[th]=ดาวน์โหลด-K
Name[tr]=KGet
Name[ug]=KGet
Name[uk]=KGet
Name[vi]=KGet
Name[wa]=KGet
Name[xh]=KGet
Name[x-test]=xxKGetxx
Name[zh_CN]=KGet
Name[zh_HK]=KGet
Name[zh_TW]=檔案傳輸_KGet
GenericName=Download Manager
GenericName[ar]=مدير التّنزيل
GenericName[ast]=Xestor de baxaes
GenericName[be]=Праграма сцягвання файлаў
GenericName[bg]=Изтегляне на файлове
GenericName[bn]=ডাউনলোড ম্যানেজার
GenericName[br]=Merour enkargañ
GenericName[bs]=Menadžer preuzimanja
GenericName[ca]=Gestor de baixades
GenericName[ca@valencia]=Gestor de baixades
GenericName[cs]=Správce stahování
GenericName[cy]=Rheolydd Lawrlwytho
GenericName[da]=Håndtering af download
GenericName[de]=Download-Manager
GenericName[el]=Διαχειριστής λήψεων αρχείων
GenericName[en_GB]=Download Manager
GenericName[eo]=Elŝuta administrilo
GenericName[es]=Gestor de descargas
GenericName[et]=Allalaadimiste haldur
GenericName[eu]=Deskarga-kudeatzailea
GenericName[fa]=مدیر بارگیری
GenericName[fi]=Tiedostonlataaja
GenericName[fr]=Gestionnaire de téléchargements
GenericName[ga]=Bainisteoir Íosluchtaithe
GenericName[gl]=Xestor de transferencias
GenericName[he]=מנהל הורדות
GenericName[hi]=डाउनलोड  प्रबंधक
GenericName[hne]=डाउनलोड  प्रबंधक
GenericName[hr]=Upravitelj preuzimanja
GenericName[hu]=Letöltéskezelő
GenericName[ia]=Gerente de discargamento
GenericName[is]=Niðurhalsstjóri
GenericName[it]=Gestore degli scaricamenti
GenericName[ja]=ダウンロードマネージャ
GenericName[kk]=Жүктеп алу менеджері
GenericName[km]=កម្មវិធី​គ្រប់គ្រង​ការ​ទាញយក
GenericName[ko]=다운로드 관리자
GenericName[lt]=Siuntimų valdymas
GenericName[lv]=Lejupielāžu pārvaldnieks
GenericName[mk]=Менаџер за симнувања
GenericName[ml]=ഇറക്കിവെക്കല്‍ കാര്യസ്ഥന്‍
GenericName[mr]=डाउनलोड व्यवस्थापक
GenericName[nb]=Nedlastingsbehandler
GenericName[nds]=Daalladenpleger
GenericName[ne]=डाउनलोड प्रबन्धक
GenericName[nl]=Downloadbeheerder
GenericName[nn]=Nedlastingshandsamar
GenericName[pa]=ਡਾਊਨਲੋਡ ਮੈਨੇਜਰ
GenericName[pl]=Menedżer pobierania
GenericName[pt]=Gestor de Transferências
GenericName[pt_BR]=Gerenciador de downloads
GenericName[ro]=Administrator descărcări
GenericName[ru]=Диспетчер загрузок
GenericName[si]=බාගැනීම් කළමනාකරු
GenericName[sk]=Správca sťahovania
GenericName[sl]=Upravitelj prenosov
GenericName[sq]=Organizuesi i Shkarkimeve
GenericName[sr]=Менаџер преузимања
GenericName[sr@ijekavian]=Менаџер преузимања
GenericName[sr@ijekavianlatin]=Menadžer preuzimanja
GenericName[sr@latin]=Menadžer preuzimanja
GenericName[sv]=Nerladdningshanterare
GenericName[ta]=பதிவிறக்க மேலாளர்
GenericName[tg]=Мудири Боркунӣ
GenericName[th]=เครื่องมือจัดการการดาวน์โหลด
GenericName[tr]=İndirme Yöneticisi
GenericName[ug]=چۈشۈرۈش باشقۇرغۇسى
GenericName[uk]=Керування звантаженнями
GenericName[uz]=Yozib olish boshqaruvchisi
GenericName[uz@cyrillic]=Ёзиб олиш бошқарувчиси
GenericName[vi]=Trình quản lý việc tải tập tin
GenericName[wa]=Manaedjeu d' aberwetaedje
GenericName[x-test]=xxDownload Managerxx
GenericName[zh_CN]=下载管理器
GenericName[zh_HK]=下載管理員
GenericName[zh_TW]=下載管理員
Categories=Qt;KDE;Network;FileTransfer;
X-DBUS-ServiceType=Unique
X-DocPath=kget/index.html

==> kget-4.12.2.tar.xz: kget-4.12.2/desktop/kget.desktop.cmake <==
# KDE Config File
[Desktop Entry]
Type=Application
Exec=kget -caption %c %i %U
Icon=kget
Terminal=false
MimeType=@SUPPORTED_KGET_MIMETYPES@
Name=KGet
Name[ar]=KGet
Name[ast]=KGet
Name[be]=KGet
Name[bg]=KGet
Name[bn]=কে-গেট
Name[br]=KGet
Name[bs]=KGet
Name[ca]=KGet
Name[ca@valencia]=KGet
Name[cs]=KGet
Name[cy]=KNôl
Name[da]=KGet
Name[de]=KGet
Name[el]=KGet
Name[en_GB]=KGet
Name[eo]=KGet
Name[es]=KGet
Name[et]=KGet
Name[eu]=KGet
Name[fi]=KGet
Name[fr]=KGet
Name[ga]=KGet
Name[gl]=KGet
Name[he]=KGet
Name[hi]=के-गेट
Name[hne]=के-गेट
Name[hr]=KGet
Name[hu]=KGet
Name[ia]=KGet
Name[is]=KGet
Name[it]=KGet
Name[ja]=KGet
Name[kk]=KGet
Name[km]=KGet
Name[ko]=KGet
Name[lt]=KGet
Name[lv]=KGet
Name[mk]=KGet
Name[ml]=കെഗെറ്റ്
Name[mr]=के-गेट
Name[ms]=KGet
Name[nb]=KGet
Name[nds]=KGet
Name[ne]=केडीई गेट
Name[nl]=KGet
Name[nn]=KGet
Name[pa]=ਕੇ-ਗੈੱਟ
Name[pl]=KGet
Name[pt]=KGet
Name[pt_BR]=KGet
Name[ro]=KGet
Name[ru]=KGet
Name[se]=KGet
Name[si]=KGet
Name[sk]=KGet
Name[sl]=KGet
Name[sq]=KGet
Name[sr]=К‑гет
Name[sr@ijekavian]=К‑гет
Name[sr@ijekavianlatin]=KGet
Name[sr@latin]=KGet
Name[sv]=Kget
Name[ta]=கேகெட்
Name[tg]=KGet
Name[th]=ดาวน์โหลด-K
Name[tr]=KGet
Name[ug]=KGet
Name[uk]=KGet
Name[vi]=KGet
Name[wa]=KGet
Name[xh]=KGet
Name[x-test]=xxKGetxx
Name[zh_CN]=KGet
Name[zh_HK]=KGet
Name[zh_TW]=檔案傳輸_KGet
GenericName=Download Manager
GenericName[ar]=مدير التّنزيل
GenericName[ast]=Xestor de baxaes
GenericName[be]=Праграма сцягвання файлаў
GenericName[bg]=Изтегляне на файлове
GenericName[bn]=ডাউনলোড ম্যানেজার
GenericName[br]=Merour enkargañ
GenericName[bs]=Menadžer preuzimanja
GenericName[ca]=Gestor de baixades
GenericName[ca@valencia]=Gestor de baixades
GenericName[cs]=Správce stahování
GenericName[cy]=Rheolydd Lawrlwytho
GenericName[da]=Håndtering af download
GenericName[de]=Download-Manager
GenericName[el]=Διαχειριστής λήψεων αρχείων
GenericName[en_GB]=Download Manager
GenericName[eo]=Elŝuta administrilo
GenericName[es]=Gestor de descargas
GenericName[et]=Allalaadimiste haldur
GenericName[eu]=Deskarga-kudeatzailea
GenericName[fa]=مدیر بارگیری
GenericName[fi]=Tiedostonlataaja
GenericName[fr]=Gestionnaire de téléchargements
GenericName[ga]=Bainisteoir Íosluchtaithe
GenericName[gl]=Xestor de transferencias
GenericName[he]=מנהל הורדות
GenericName[hi]=डाउनलोड  प्रबंधक
GenericName[hne]=डाउनलोड  प्रबंधक
GenericName[hr]=Upravitelj preuzimanja
GenericName[hu]=Letöltéskezelő
GenericName[ia]=Gerente de discargamento
GenericName[is]=Niðurhalsstjóri
GenericName[it]=Gestore degli scaricamenti
GenericName[ja]=ダウンロードマネージャ
GenericName[kk]=Жүктеп алу менеджері
GenericName[km]=កម្មវិធី​គ្រប់គ្រង​ការ​ទាញយក
GenericName[ko]=다운로드 관리자
GenericName[lt]=Siuntimų valdymas
GenericName[lv]=Lejupielāžu pārvaldnieks
GenericName[mk]=Менаџер за симнувања
GenericName[ml]=ഇറക്കിവെക്കല്‍ കാര്യസ്ഥന്‍
GenericName[mr]=डाउनलोड व्यवस्थापक
GenericName[nb]=Nedlastingsbehandler
GenericName[nds]=Daalladenpleger
GenericName[ne]=डाउनलोड प्रबन्धक
GenericName[nl]=Downloadbeheerder
GenericName[nn]=Nedlastingshandsamar
GenericName[pa]=ਡਾਊਨਲੋਡ ਮੈਨੇਜਰ
GenericName[pl]=Menedżer pobierania
GenericName[pt]=Gestor de Transferências
GenericName[pt_BR]=Gerenciador de downloads
GenericName[ro]=Administrator descărcări
GenericName[ru]=Диспетчер загрузок
GenericName[si]=බාගැනීම් කළමනාකරු
GenericName[sk]=Správca sťahovania
GenericName[sl]=Upravljalnik prenosov
GenericName[sq]=Organizuesi i Shkarkimeve
GenericName[sr]=Менаџер преузимања
GenericName[sr@ijekavian]=Менаџер преузимања
GenericName[sr@ijekavianlatin]=Menadžer preuzimanja
GenericName[sr@latin]=Menadžer preuzimanja
GenericName[sv]=Nerladdningshanterare
GenericName[ta]=பதிவிறக்க மேலாளர்
GenericName[tg]=Мудири Боркунӣ
GenericName[th]=เครื่องมือจัดการการดาวน์โหลด
GenericName[tr]=İndirme Yöneticisi
GenericName[ug]=چۈشۈرۈش باشقۇرغۇسى
GenericName[uk]=Керування звантаженнями
GenericName[uz]=Yozib olish boshqaruvchisi
GenericName[uz@cyrillic]=Ёзиб олиш бошқарувчиси
GenericName[vi]=Trình quản lý việc tải tập tin
GenericName[wa]=Manaedjeu d' aberwetaedje
GenericName[x-test]=xxDownload Managerxx
GenericName[zh_CN]=下载管理器
GenericName[zh_HK]=下載管理員
GenericName[zh_TW]=下載管理員
Categories=Qt;KDE;Network;FileTransfer;
X-DBUS-ServiceType=Unique
X-DocPath=kget/index.html
